@@ -31,7 +31,7 @@ class PrintOptions : public QWidget, private Ui::PrintOptions
     Q_OBJECT
 
 public:
-    PrintOptions(QWidget* parent = 0);
+    explicit PrintOptions(QWidget* parent = 0);
     ~PrintOptions();
 
 public slots:
